==> Pyrogram-1.2.8-py3-none-any.whl: pyrogram/raw/functions/phone/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_call_config import GetCallConfig
from .request_call import RequestCall
from .accept_call import AcceptCall
from .confirm_call import ConfirmCall
from .received_call import ReceivedCall
from .discard_call import DiscardCall
from .set_call_rating import SetCallRating
from .save_call_debug import SaveCallDebug
from .send_signaling_data import SendSignalingData
from .create_group_call import CreateGroupCall
from .join_group_call import JoinGroupCall
from .leave_group_call import LeaveGroupCall
from .invite_to_group_call import InviteToGroupCall
from .discard_group_call import DiscardGroupCall
from .toggle_group_call_settings import ToggleGroupCallSettings
from .get_group_call import GetGroupCall
from .get_group_participants import GetGroupParticipants
from .check_group_call import CheckGroupCall
from .toggle_group_call_record import ToggleGroupCallRecord
from .edit_group_call_participant import EditGroupCallParticipant
from .edit_group_call_title import EditGroupCallTitle
from .get_group_call_join_as import GetGroupCallJoinAs
from .export_group_call_invite import ExportGroupCallInvite

==> Pyrogram-1.2.20-py3-none-any.whl: pyrogram/raw/functions/phone/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .get_call_config import GetCallConfig
from .request_call import RequestCall
from .accept_call import AcceptCall
from .confirm_call import ConfirmCall
from .received_call import ReceivedCall
from .discard_call import DiscardCall
from .set_call_rating import SetCallRating
from .save_call_debug import SaveCallDebug
from .send_signaling_data import SendSignalingData
from .create_group_call import CreateGroupCall
from .join_group_call import JoinGroupCall
from .leave_group_call import LeaveGroupCall
from .invite_to_group_call import InviteToGroupCall
from .discard_group_call import DiscardGroupCall
from .toggle_group_call_settings import ToggleGroupCallSettings
from .get_group_call import GetGroupCall
from .get_group_participants import GetGroupParticipants
from .check_group_call import CheckGroupCall
from .toggle_group_call_record import ToggleGroupCallRecord
from .edit_group_call_participant import EditGroupCallParticipant
from .edit_group_call_title import EditGroupCallTitle
from .get_group_call_join_as import GetGroupCallJoinAs
from .export_group_call_invite import ExportGroupCallInvite
from .toggle_group_call_start_subscription import ToggleGroupCallStartSubscription
from .start_scheduled_group_call import StartScheduledGroupCall
from .save_default_group_call_join_as import SaveDefaultGroupCallJoinAs
from .join_group_call_presentation import JoinGroupCallPresentation
from .leave_group_call_presentation import LeaveGroupCallPresentation
